;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "universal-sidecar-elfeed-score" "20251029.1934"
  "Show Elfeed Score information in sidecar."
  '((emacs             "25.1")
    (universal-sidecar "1.0.0")
    (elfeed            "3.4.1")
    (elfeed-score      "1.2.6"))
  :url "https://git.sr.ht/~swflint/emacs-universal-sidecar"
  :commit "01b12aecca0ce66f5427e7fe65012d37e7e128b2"
  :revdesc "01b12aecca0c"
  :authors '(("Samuel W. Flint" . "me@samuelwflint.com"))
  :maintainers '(("Samuel W. Flint" . "me@samuelwflint.com")))
